package CPAN::Test::Dummy::Perl5::VersionQV;

use strict;
use 5.008_005;
use version 0.77; our $VERSION = qv('0.0.1');

1;
__END__

=encoding utf-8

=head1 NAME

CPAN::Test::Dummy::Perl5::VersionQV - qv() version

=head1 SYNOPSIS

  use CPAN::Test::Dummy::Perl5::VersionQV;

=head1 DESCRIPTION

CPAN::Test::Dummy::Perl5::VersionQV is a dummy CPAN distribution with the use of C<qv()> in its VERSION line.

=head1 AUTHOR

Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>

=head1 COPYRIGHT

Copyright 2013- Tatsuhiko Miyagawa

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 SEE ALSO

=cut
